/***************************************************************************
                          ks3switch.cpp  -  description
                             -------------------
    begin                : jeu jui 11 21:59:30 CEST 2002
    copyright            : (C) 2002 by Francois Bochatay
    email                : francois.bochatay@epfl.ch
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ks3switch.h"

#include <klocale.h>
#include <kglobal.h>
#include <kiconloader.h>
#include <kaction.h>
#include <kstdaction.h>
#include <kpopupmenu.h>
#include <kurlrequester.h>
#include <kprocio.h>
#include <qcursor.h>
#include <qradiobutton.h>
#include <qtooltip.h>

KS3Switch::KS3Switch(KDialog* d, QWidget *parent, const char *name) : KDockWindow(parent, name), actionCollection(this), aboutDialog(d)
{
/** Set the OpenOffice icon */
	KIconLoader* loader = KGlobal::iconLoader();
	icon = loader->loadIcon("ks3switch", KIcon::Toolbar);
	setPixmap(icon);

	/** Create the preferences-dialog */
	preferencesDialog = new prefDialogImpl(0);
	
	/** Define the actions */
	about = KStdAction::aboutApp(this, SLOT (showAbout()), &actionCollection);
	preferences = KStdAction::preferences (this, SLOT (openPreferences()), &actionCollection);
	lcd = new KAction(i18n("LCD"), 0, 0, 0, 0, &actionCollection, 0);
	tv = new KAction(i18n("TV"), 0, 0, 0, 0, &actionCollection, 0);
	crt = new KAction(i18n("CRT"), 0, 0, 0, 0, &actionCollection, 0);
	tv_lcd = new KAction(i18n("TV + LCD"), 0, 0, 0, 0, &actionCollection, 0);
	crt_lcd = new KAction(i18n("CRT + LCD"), 0, 0, 0, 0, &actionCollection, 0);
	crt_tv_lcd = new KAction(i18n("CRT + TV + LCD"), 0, 0, 0, 0, &actionCollection, 0);

	/** Fill the menu */
	lcd->plug(contextMenu());
	tv->plug(contextMenu());
	crt->plug(contextMenu());
	tv_lcd->plug(contextMenu());
	crt_lcd->plug(contextMenu());
	crt_tv_lcd->plug(contextMenu());
	contextMenu()->insertSeparator();
	preferences->plug(contextMenu());
	contextMenu()->insertSeparator();
	about->plug(contextMenu());

	/** Connect the actions with the slots */
	connect (lcd, SIGNAL (activated()), SLOT (swlcd()));
	connect (tv, SIGNAL (activated()), SLOT (swtv()));
	connect (crt, SIGNAL (activated()), SLOT (swcrt()));
	connect (tv_lcd, SIGNAL (activated()), SLOT (swtv_lcd()));
	connect (crt_lcd, SIGNAL (activated()), SLOT (swcrt_lcd()));
	connect (crt_tv_lcd, SIGNAL (activated()), SLOT (swcrt_tv_lcd()));
	connect (preferencesDialog, SIGNAL (success()), SLOT (changedConfig()));

	/** Read the configuration */
	config = KGlobal::config();

	/** Try to find the entries in the configfile */
	/** If the config is not accessible (e.g. not existing) */
	config->setGroup("General options");
	if (config->readBoolEntry("first", true)){
		/** Sets the TV mode and s3switch path to default */
		TV_mode = "PAL";
    s3switch = "s3switch";
	}else{
		rereadConfig();
	}
}

KS3Switch::~KS3Switch()
{
}

/** Executes the about-dialog. */
void KS3Switch::showAbout(){
	aboutDialog->exec();
}

/** Switch to LCD */
void KS3Switch::swlcd(){
	KProcess* process = new KProcess;
	*process << s3switch << "LCD";
	process->start(KProcess::DontCare);
}

/** Switch to TV */
void KS3Switch::swtv(){
	KProcess* process = new KProcess;
	*process << s3switch << "TV" << TV_mode;
	process->start(KProcess::DontCare);
}

/** Switch to CRT */
void KS3Switch::swcrt(){
	KProcess* process = new KProcess;
	*process << s3switch << "CRT";
	process->start(KProcess::DontCare);
}

/** Switch to TV + LCD */
void KS3Switch::swtv_lcd(){
	KProcess* process = new KProcess;
	*process << s3switch << "TV" << "LCD" << TV_mode;
	process->start(KProcess::DontCare);
}

/** Switch to CRT + LCD */
void KS3Switch::swcrt_lcd(){
	KProcess* process = new KProcess;
	*process << s3switch << "CRT" << "LCD";
	process->start(KProcess::DontCare);
}

/** Switch to CRT + TV + LCD */
void KS3Switch::swcrt_tv_lcd(){
	KProcess* process = new KProcess;
	*process << s3switch << "CRT" << "TV" << "LCD" << TV_mode;
	process->start(KProcess::DontCare);
}

/** Call this to open the preferences-dialog. */
void KS3Switch::openPreferences(){
	preferencesDialog->exec();
}

/** Should be called whenever the configuration changes. */
void KS3Switch::changedConfig(){
	config->setGroup("General options");
  config->writeEntry("first", false);
  config->writeEntry("exec", preferencesDialog->Exec->url());
	config->writeEntry("PAL", preferencesDialog->PAL->isChecked());
  config->writeEntry("NTSC", preferencesDialog->NTSC->isChecked());
  config->writeEntry("NTSCJ", preferencesDialog->NTSCJ->isChecked());
	config->sync();
	rereadConfig();
}

/** Call this to (re-)load the config from disk */
void KS3Switch::rereadConfig(){
	/** Reparse the configuration to be sure that the data we use is up to date */
	config->reparseConfiguration();
	/** Set the values */
	config->setGroup("General options");
  s3switch = config->readEntry("exec");
	if (s3switch.isEmpty())
	{
		s3switch = "s3switch";
	}
	if (config->readBoolEntry("PAL")){
		TV_mode = "PAL";
	}
	if (config->readBoolEntry("NTSC")){
		TV_mode = "NTSC";
	}
  if (config->readBoolEntry("NTSCJ")){
		TV_mode = "NTSCJ";
  }

	/** Set the widgets in the preferences dialog to the current values */
	config->setGroup("General options");
  preferencesDialog->Exec->setURL(s3switch);
	preferencesDialog->PAL->setChecked(config->readBoolEntry("PAL"));
	preferencesDialog->NTSC->setChecked(config->readBoolEntry("NTSC"));
	preferencesDialog->NTSCJ->setChecked(config->readBoolEntry("NTSCJ"));
}
