/***************************************************************************
                          ks3switch.h  -  description
                             -------------------
    begin                : jeu jui 11 21:59:30 CEST 2002
    copyright            : (C) 2002 by Francois Bochatay
    email                : francois.bochatay@epfl.ch
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KS3SWITCH_H
#define KS3SWITCH_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapp.h>
#include <kdockwindow.h>
#include <kpixmap.h>
#include <kaction.h>
#include <kdialog.h>
#include <kprocess.h>
#include <prefdialogimpl.h>
#include <kconfig.h>
#include <kurl.h>
#include <kfiledialog.h>

/** KS3Switch is the base class of the project */
class KS3Switch : public KDockWindow
{
  Q_OBJECT
  public:
    /** construtor */
    KS3Switch(KDialog* d, QWidget* parent=0, const char *name=0);
    /** destructor */
    ~KS3Switch();

  private: // Private attributes
    /** Saves the KS3Switch icon */
    KPixmap icon;
    /** Saves the chosen TV mode */
    QString TV_mode;
    /** Saves the path to s3switch */
    QString s3switch;
    /** The actionCollection containing the contextmenu-entrys */
    KActionCollection actionCollection;
    /** The action that switch to LCD */
    KAction* lcd;
    /** The action that switch to TV */
    KAction* tv;
    /** The action that switch to CRT */
    KAction* crt;
    /** The action that switch to TV + LCD */
    KAction* tv_lcd;
    /** The action that switch to CRT + LCD */
    KAction* crt_lcd;
    /** The action that switch to CRT + TV + LCD */
    KAction* crt_tv_lcd;
    /** The action that show the about window */
    KAction* about;
    /** The action that show the preferences window */
    KAction* preferences;
    /** The quit-item */
    KAction* quit;
    /** The about-dialog */
    KDialog* aboutDialog;
    /** The dialog where we'll configure the few settings available for KS3Ssitch. */
    prefDialog* preferencesDialog;
    /** The configuration used by KS3Ssitch */
    KConfig* config;
  private slots: // Private slots
    /** Switch to LCD */
    void swlcd();
    /** Switch to TV */
    void swtv();
    /** Switch to CRT */
    void swcrt();
    /** Switch to TV + LCD */
    void swtv_lcd();
    /** Switch to CRT + LCD */
    void swcrt_lcd();
    /** Switch to CRT + TV + LCD */
    void swcrt_tv_lcd();
    /** Executes the about-dialog. */
    void showAbout();
    /** Call this to open the preferences-dialog. */
    void openPreferences();
    /** Should be called whenever the configuration changes. */
    void changedConfig();
  private:
    /** Call this to (re-)load the config from disk */
    void rereadConfig();
};

#endif
